/**
 * Class for dealing with static scoring.
 */

package org.ucam.srcf.assassins.strawberry;

import java.util.Map;

import org.ucam.srcf.assassins.Death;
import org.ucam.srcf.assassins.exceptions.AssassinSQLException;

public interface StaticScoringAlgorithm {
   /**
    * Initilise algorithm. 
    * Will be called before any other functions.
    * @param n Maximum number of assassins the algorithm has to deal with
    */
   public void init (int n);

   /** 
    * Scores the deaths the algorithm knows about.
    * This will be the last call made to the algorithm.
    * @return Map from AssassinViewer to Double representing score.
    */
   public Map score();

   /**
    * Tell the algorithm about a death.
    * May assume score() hasn't been called yet.
    * @param d Death we're telling it about.
    */
   public void addDeath(Death d) throws AssassinSQLException;
}
